@@ -1,22 +1,20 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
+use 5.010;
+use warnings;
+use strict;
 
 package Language::Befunge;
-require 5.010;
-
-use strict;
-use warnings;
-
+# ABSTRACT: a generic funge interpreter
+$Language::Befunge::VERSION = '5.000';
 use Language::Befunge::Interpreter;
 
-# Public variables of the module.
-our $VERSION = '4.13';
 $| = 1;
 
 sub new {
@@ -25,13 +23,20 @@ sub new {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Language::Befunge - a generic funge interpreter
 
+=head1 VERSION
 
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -46,8 +51,6 @@ Language::Befunge - a generic funge interpreter
     END_OF_CODE
     $interp->run_code;
 
-
-
 =head1 DESCRIPTION
 
 Enter the realm of topological languages!
@@ -73,11 +76,8 @@ Lahey-Space topology to be more precise) looks like the following:
                      y|2,147,483,647
                       v
 
-
 This module also implements the Concurrent Funge semantics.
 
-
-
 =head1 PUBLIC METHODS
 
 =head2 new( [params] )
@@ -85,8 +85,6 @@ This module also implements the Concurrent Funge semantics.
 Call directly the C<Language::Befunge::Interpreter> constructor. Refer
 to L<Language::Befunge::Interpreter> for more information.
 
-
-
 =head1 BUGS
 
 Although this module comes with a full set of tests, there may be subtle bugs
@@ -97,7 +95,6 @@ the web interface at
 notified, and then you'll automatically be notified of progress on your bug as
 I make changes.
 
-
 Here is a list of known "bugs", coming from the specs:
 
 =over 4
@@ -123,8 +120,6 @@ numbers greater than C<0xffffffff>.
 
 =back
 
-
-
 =head1 ACKNOWLEDGEMENTS
 
 I would like to thank Chris Pressey, creator of Befunge, who gave a
@@ -133,19 +128,15 @@ whole new dimension to both coding and obfuscating.
 Thanks also to Matti Niemenmaa for his mycology test suite, available at
 L<http://users.tkk.fi/~mniemenm/befunge/mycology.html>
 
-
-
 =head1 SEE ALSO
 
 You can find more information on Befunge at
 L<http://www.catseye.mb.ca/esoteric/befunge/>.
 
-Our git repository is located at L<git://repo.or.cz/language-befunge.git>, and
-can be browsed at L<http://repo.or.cz/w/language-befunge.git>.
+Our git repository is located at L<https://github.com/jquelin/language-befunge>.
 
 You can also look for information on this module at:
 
-
 =over 4
 
 =item * AnnoCPAN: Annotated CPAN documentation
@@ -162,22 +153,15 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Language-Befunge>
 
 =back
 
-
-
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
-Development is discussed on C<< <language-befunge@mongueurs.net> >>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
