@@ -1,17 +1,18 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::IP;
-require 5.010;
-
+use 5.010;
 use strict;
 use warnings;
+
+package Language::Befunge::IP;
+# ABSTRACT: an Instruction Pointer for a Befunge-98 program
+$Language::Befunge::IP::VERSION = '5.000';
 use integer;
 
 use Carp;
@@ -422,13 +423,20 @@ sub _get_new_id {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Language::Befunge::IP - an Instruction Pointer for a Befunge-98 program.
+Language::Befunge::IP - an Instruction Pointer for a Befunge-98 program
 
+=head1 VERSION
 
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -439,8 +447,6 @@ can be manipulated via the methods of the class.
 We need a class, since this is a concurrent Befunge, so we can have
 more than one IP travelling on the Lahey space.
 
-
-
 =head1 CONSTRUCTORS
 
 =head2 my $ip = LB::IP->new( [$dimensions] )
@@ -449,14 +455,11 @@ Create a new Instruction Pointer, which operates in a universe of the given
 C<$dimensions>. If C<$dimensions> is not specified, it defaults to 2
 (befunge world).
 
-
 =head2 my $clone = $ip->clone()
 
 Clone the current Instruction Pointer with all its stacks, position,
 delta, etc. Change its unique ID.
 
-
-
 =head1 ACCESSORS
 
 =head2 Attributes
@@ -465,84 +468,69 @@ The following is a list of attributes of a Language::Befunge::IP
 object. For each of them, a method C<get_foobar> and C<set_foobar>
 exists.
 
-
 =over 4
 
 =item $ip->get_id() / $ip->set_id($id)
 
 The unique ID of the IP (an integer). Don't set the ID yourself.
 
-
 =item $ip->get_dims()
 
 The number of dimensions this IP operates in (an integer). This is
 read-only.
 
-
 =item $ip->get_position() / $ip->set_position($vec)
 
 The current coordinates of the IP (a C<Language::Befunge::Vector>
 object).
 
-
 =item $ip->get_delta() / $ip->set_delta($vec)
 
 The velocity of the IP (a C<Language::Befunge::Vector> object).
 
-
 =item $ip->get_storage() / $ip->set_storage($vec)
 
 The coordinates of the storage offset of the IP (a
 C<Language::Befunge::Vector> object).
 
-
 =item $ip->get_data() / $ip->set_data({})
 
 The library private storage space (a hash reference). Don't set this
 yourself.
 FIXME: not supposed to be accessible
 
-
 =item $ip->get_string_mode() / set_string_mode($bool)
 
 The string_mode of the IP (a boolean).
 
-
 =item $ip->get_end() / $ip->set_end($bool)
 
 Whether the IP should be terminated (a boolean).
 
-
 =item $ip->get_libs() / $ip->set_libs($aref)
 
 The current stack of loaded libraries (an array reference). Don't set
 this yourself.
 FIXME: not supposed to be accessible
 
-
 =item $ip->get_ss() / $ip->set_ss($aref)
 
 The stack of stack of the IP (an array reference). Don't set this
 yourself.
 FIXME: not supposed to be accessible
 
-
 =item $ip->get_toss() / $ip->set_toss($aref)
 
 The current stack (er, TOSS) of the IP (an array reference). Don't set
 this yourself.
 FIXME: not supposed to be accessible
 
-
 =back
 
-
 =head2 $ip->soss([$])
 
 Get or set the SOSS.
 
-
-
 =head1 PUBLIC METHODS
 
 =head2 Internal stack
@@ -553,24 +541,20 @@ is, the Top Of the Stack Stack.
 In Befunge-98, standard stack operations occur transparently on the
 TOSS (as if there were only one stack, as in Befunge-93).
 
-
 =over 4
 
 =item scount(  )
 
 Return the number of elements in the stack.
 
-
 =item spush( value )
 
 Push a value on top of the stack.
 
-
 =item spush_vec( vector )
 
 Push a vector on top of the stack. The x coordinate is pushed first.
 
-
 =item spush_args ( arg, ... )
 
 Push a list of argument on top of the stack (the first argument will
@@ -580,34 +564,28 @@ whereas a string is pushed as a 0gnirts.
 B</!\> Do B<not> push references or weird arguments: this method
 supports only numbers (positive and negative) and strings.
 
-
 =item spop(  )
 
 Pop a value from the stack. If the stack is empty, no error occurs and
 the method acts as if it popped a 0.
 
-
 =item spop_mult( <count> )
 
 Pop multiple values from the stack. If the stack becomes empty, the
 remainder of the returned values will be 0.
 
-
 =item spop_vec(  )
 
 Pop a vector from the stack. Returns a Vector object.
 
-
 =item spop_gnirts(  )
 
 Pop a 0gnirts string from the stack.
 
-
 =item sclear(  )
 
 Clear the stack.
 
-
 =item svalue( offset )
 
 Return the C<offset>th value of the TOSS, counting from top of the
@@ -615,10 +593,8 @@ TOSS. The offset is interpreted as a negative value, that is, a call
 with an offset of C<2> or C<-2> would return the second value on top
 of the TOSS.
 
-
 =back
 
-
 =head2 Stack stack
 
 This section discusses about the stack stack. We can speak here about
@@ -631,8 +607,6 @@ TOSS (Top Of Stack Stack) and SOSS (second on stack stack).
 Return the number of stacks in the stack stack. This of course does
 not include the TOSS itself.
 
-
-
 =item ss_create( count )
 
 Push the TOSS on the stack stack and create a new stack, aimed to be
@@ -642,13 +616,11 @@ copy -, furthermore, order is preserved.
 
 If count is negative, then C<count> zeroes are pushed on the new TOSS.
 
-
 =item ss_remove( count )
 
 Move C<count> elements from TOSS to SOSS, discard TOSS and make the
 SOSS become the new TOSS. Order of elems is preserved.
 
-
 =item ss_transfer( count )
 
 Transfer C<count> elements from SOSS to TOSS, or from TOSS to SOSS if
@@ -656,55 +628,44 @@ C<count> is negative; the transfer is done via pop/push.
 
 The order is not preserved, it is B<reversed>.
 
-
 =item ss_sizes(  )
 
 Return a list with all the sizes of the stacks in the stack stack
 (including the TOSS), from the TOSS to the BOSS.
 
-
 =item soss_count(  )
 
 Return the number of elements in SOSS.
 
-
 =item soss_push( value )
 
 Push a value on top of the SOSS.
 
-
 =item soss_pop_mult( <count> )
 
 Pop multiple values from the SOSS. If the stack becomes empty, the
 remainder of the returned values will be 0.
 
-
 =item soss_push_vec( vector )
 
 Push a vector on top of the SOSS.
 
-
-
 =item soss_pop(  )
 
 Pop a value from the SOSS. If the stack is empty, no error occurs and
 the method acts as if it popped a 0.
 
-
 =item soss_pop_vec(  )
 
 Pop a vector from the SOSS. If the stack is empty, no error occurs
 and the method acts as if it popped a 0.  returns a Vector.
 
-
 =item soss_clear(  )
 
 Clear the SOSS.
 
-
 =back
 
-
 =head2 Changing direction
 
 =over 4
@@ -713,47 +674,40 @@ Clear the SOSS.
 
 Implements the C<E<gt>> instruction. Force the IP to travel east.
 
-
 =item dir_go_west(  )
 
 Implements the C<E<lt>> instruction. Force the IP to travel west.
 
-
 =item dir_go_north(  )
 
 Implements the C<^> instruction. Force the IP to travel north.
 
 Not valid for Unefunge.
 
-
 =item dir_go_south(  )
 
 Implements the C<v> instruction. Force the IP to travel south.
 
 Not valid for Unefunge.
 
-
 =item dir_go_high(  )
 
 Implements the C<h> instruction. Force the IP to travel up.
 
 Not valid for Unefunge or Befunge.
 
-
 =item dir_go_low(  )
 
 Implements the C<l> instruction. Force the IP to travel down.
 
 Not valid for Unefunge or Befunge.
 
-
 =item dir_go_away(  )
 
 Implements the C<?> instruction. Cause the IP to travel in a random
 cardinal direction (in Befunge's case, one of: north, south, east or
 west).
 
-
 =item dir_turn_left(  )
 
 Implements the C<[> instruction. Rotate by 90 degrees on the left the
@@ -762,7 +716,6 @@ delta of the IP which encounters this instruction.
 Not valid for Unefunge.  For Trefunge and greater, only affects the
 X and Y axes.
 
-
 =item dir_turn_right(  )
 
 Implements the C<]> instruction. Rotate by 90 degrees on the right the
@@ -771,15 +724,11 @@ delta of the IP which encounters this instruction.
 Not valid for Unefunge.  For Trefunge and higher dimensions, only
 affects the X and Y axes.
 
-
-
 =item dir_reverse(  )
 
 Implements the C<r> instruction. Reverse the direction of the IP, that
 is, multiply the IP's delta by -1.
 
-
-
 =back
 
 =head2 Libraries semantics
@@ -791,8 +740,6 @@ is, multiply the IP's delta by -1.
 Load the given library semantics. The parameter is an extension object
 (a library instance).
 
-
-
 =item unload( lib )
 
 Unload the given library semantics. The parameter is the library name.
@@ -805,7 +752,6 @@ unload the most recent library. Ie, if an IP has loaded the libraries
 then the IP will follow the semantics of C<BAZ>, then C<BAR>, then
 <FOO> (!).
 
-
 =item extdata( library, [value] )
 
 Store or fetch a value in a private space. This private space is
@@ -816,26 +762,15 @@ to an array or even a hash.
 
 =back
 
-
-
-
-=head1 SEE ALSO
-
-L<Language::Befunge>.
-
-
 =head1 AUTHOR
 
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
