@@ -1,18 +1,18 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Interpreter;
 use 5.010;
-
 use strict;
 use warnings;
 
+package Language::Befunge::Interpreter;
+# ABSTRACT: an interpreter for Language::Befunge
+$Language::Befunge::Interpreter::VERSION = '5.000';
 use Carp;
 use Language::Befunge::Debug;
 use Language::Befunge::IP;
@@ -114,32 +114,28 @@ sub new {
     my $lbo = 'Language::Befunge::Ops::';
     my $lbs = 'Language::Befunge::Storage::';
     my $lbw = 'Language::Befunge::Wrapping::';
-    given ( $opts->{syntax} ) {
-        when ('unefunge98') {
-            $opts->{dims}     = 1                     unless defined $opts->{dims};
-            $opts->{ops}      = $lbo . 'Unefunge98'   unless defined $opts->{ops};
-            $opts->{storage}  = $lbs . 'Generic::AoA' unless defined $opts->{storage};
-            $opts->{wrapping} = $lbw . 'LaheySpace'   unless defined $opts->{wrapping};
-        }
-        when ('befunge98') {
-            $opts->{dims}     = 2                     unless defined $opts->{dims};
-            $opts->{ops}      = $lbo . 'Befunge98'    unless defined $opts->{ops};
-            $opts->{storage}  = $lbs . '2D::Sparse'   unless defined $opts->{storage};
-            $opts->{wrapping} = $lbw . 'LaheySpace'   unless defined $opts->{wrapping};
-        }
-        when ('trefunge98') {
-            $opts->{dims}     = 3                       unless defined $opts->{dims};
-            $opts->{ops}      = $lbo . 'GenericFunge98' unless defined $opts->{ops};
-            $opts->{storage}  = $lbs . 'Generic::AoA'   unless defined $opts->{storage};
-            $opts->{wrapping} = $lbw . 'LaheySpace'     unless defined $opts->{wrapping};
-        }
-        when (/(\d+)funge98$/) { # accept values like "4funge98"
-            $opts->{dims}     = $1                      unless defined $opts->{dims};
-            $opts->{ops}      = $lbo . 'GenericFunge98' unless defined $opts->{ops};
-            $opts->{storage}  = $lbs . 'Generic::AoA'   unless defined $opts->{storage};
-            $opts->{wrapping} = $lbw . 'LaheySpace'     unless defined $opts->{wrapping};
-        }
-        default { croak "syntax '$opts->{syntax}' not recognized." }
+    if ( $opts->{syntax} eq 'unefunge98' ) {
+        $opts->{dims}     = 1                     unless defined $opts->{dims};
+        $opts->{ops}      = $lbo . 'Unefunge98'   unless defined $opts->{ops};
+        $opts->{storage}  = $lbs . 'Generic::AoA' unless defined $opts->{storage};
+        $opts->{wrapping} = $lbw . 'LaheySpace'   unless defined $opts->{wrapping};
+    } elsif ( $opts->{syntax} eq 'befunge98' ) {
+        $opts->{dims}     = 2                     unless defined $opts->{dims};
+        $opts->{ops}      = $lbo . 'Befunge98'    unless defined $opts->{ops};
+        $opts->{storage}  = $lbs . '2D::Sparse'   unless defined $opts->{storage};
+        $opts->{wrapping} = $lbw . 'LaheySpace'   unless defined $opts->{wrapping};
+    } elsif ( $opts->{syntax} eq 'trefunge98' ) {
+        $opts->{dims}     = 3                       unless defined $opts->{dims};
+        $opts->{ops}      = $lbo . 'GenericFunge98' unless defined $opts->{ops};
+        $opts->{storage}  = $lbs . 'Generic::AoA'   unless defined $opts->{storage};
+        $opts->{wrapping} = $lbw . 'LaheySpace'     unless defined $opts->{wrapping};
+    } elsif ( $opts->{syntax} =~ /(\d+)funge98$/ ) {
+        $opts->{dims}     = $1                      unless defined $opts->{dims};
+        $opts->{ops}      = $lbo . 'GenericFunge98' unless defined $opts->{ops};
+        $opts->{storage}  = $lbs . 'Generic::AoA'   unless defined $opts->{storage};
+        $opts->{wrapping} = $lbw . 'LaheySpace'     unless defined $opts->{wrapping};
+    } else {
+        croak "syntax '$opts->{syntax}' not recognized.";
     }
 
     # load the classes (through UNIVERSAL::require)
@@ -491,8 +487,21 @@ sub _move_ip_till {
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Language::Befunge::Interpreter - an interpreter for Language::Befunge
+
+=head1 VERSION
+
+version 5.000
+
 =head1 CONSTRUCTOR
 
 =head2 new( [filename, ] [ Key => Value, ... ] )
@@ -563,7 +572,6 @@ the C<LB::Wrapping> object driving wrapping policy. Private.
 
 =back
 
-
 =head1 PUBLIC METHODS
 
 =head2 Utilities
@@ -581,29 +589,22 @@ Example: given the code C<;foobar;> (assuming the IP points on the
 first C<;>) and the regex C<qr/[^;]/>, the IP will move in order to
 point on the C<r>.
 
-
 =item abort( reason )
 
 Abort the interpreter with the given reason, as well as the current
 file and coordinate of the offending instruction.
 
-
-
 =item set_input( $string )
 
 Preload the input buffer with the given value.
 
-
 =item get_input(  )
 
 Fetch a character of input from the input buffer, or else, directly
 from stdin.
 
-
 =back
 
-
-
 =head2 Code and Data Storage
 
 =over 4
@@ -614,18 +615,14 @@ Read a file (given as argument) and store its code.
 
 Side effect: clear the previous code.
 
-
 =item store_code( code )
 
 Store the given code in the Lahey space.
 
 Side effect: clear the previous code.
 
-
 =back
 
-
-
 =head2 Run methods
 
 =over 4
@@ -637,20 +634,16 @@ move it around the code.
 
 Return the exit code of the program.
 
-
 =item next_tick(  )
 
 Finish the current tick and stop just before the next tick.
 
-
 =item process_ip(  )
 
 Process the current ip.
 
-
 =back
 
-
 =head1 TODO
 
 =over 4
@@ -661,7 +654,6 @@ Write standard libraries.
 
 =back
 
-
 =head1 BUGS
 
 Although this module comes with a full set of tests, maybe there are
@@ -693,32 +685,15 @@ numbers greater than C<0xffffffff>.
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-I would like to thank Chris Pressey, creator of Befunge, who gave a
-whole new dimension to both coding and obfuscating.
-
-
-=head1 SEE ALSO
-
-L<Language::Befunge>
-
-
 =head1 AUTHOR
 
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
-Development is discussed on E<lt>language-befunge@mongueurs.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
