@@ -1,45 +1,23 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Ops;
-require 5.010;
-
+use 5.010;
 use strict;
 use warnings;
 
+package Language::Befunge::Ops;
+# ABSTRACT: definition of the various operations
+$Language::Befunge::Ops::VERSION = '5.000';
+
 use File::Spec::Functions qw{ catfile };   # For the 'y' instruction.
 use Language::Befunge::Debug;
 
 
-=head1 NAME
-
-Language::Befunge::Ops - definition of the various operations
-
-
-=head1 DESCRIPTION
-
-This module implements the various befunge operations. Not all those
-operations will be supported by the interpreter though, it will depend
-on the type of befunge chosen.
-
-
-=head1 SUBROUTINES
-
-=head2 Numbers
-
-=over 4
-
-=item num_push_number(  )
-
-Push the current number onto the TOSS.
-
-=cut
 sub num_push_number {
     my ($lbi, $char) = @_;
 
@@ -54,17 +32,6 @@ sub num_push_number {
     debug( "pushing number '$num'\n" );
 }
 
-=back
-
-
-
-=head2 Strings
-
-=over 4
-
-=item str_enter_string_mode(  )
-
-=cut
 sub str_enter_string_mode {
     my ($lbi) = @_;
 
@@ -76,9 +43,6 @@ sub str_enter_string_mode {
 }
 
 
-=item str_fetch_char(  )
-
-=cut
 sub str_fetch_char {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -96,9 +60,6 @@ sub str_fetch_char {
 }
 
 
-=item str_store_char(  )
-
-=cut
 sub str_store_char {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -117,17 +78,6 @@ sub str_store_char {
     debug( "storing value $val (char='$chr')\n" );
 }
 
-=back
-
-
-
-=head2 Mathematical operations
-
-=over 4
-
-=item math_addition(  )
-
-=cut
 sub math_addition {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -146,9 +96,6 @@ sub math_addition {
 }
 
 
-=item math_substraction(  )
-
-=cut
 sub math_substraction {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -167,9 +114,6 @@ sub math_substraction {
 }
 
 
-=item math_multiplication(  )
-
-=cut
 sub math_multiplication {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -188,9 +132,6 @@ sub math_multiplication {
 }
 
 
-=item math_division(  )
-
-=cut
 sub math_division {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -207,9 +148,6 @@ sub math_division {
 }
 
 
-=item math_remainder(  )
-
-=cut
 sub math_remainder {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -225,17 +163,6 @@ sub math_remainder {
     $ip->spush( $res );
 }
 
-=back
-
-
-
-=head2 Direction changing
-
-=over 4
-
-=item dir_go_east(  )
-
-=cut
 sub dir_go_east {
     my ($lbi) = @_;
     debug( "going east\n" );
@@ -243,9 +170,6 @@ sub dir_go_east {
 }
 
 
-=item dir_go_west(  )
-
-=cut
 sub dir_go_west {
     my ($lbi) = @_;
     debug( "going west\n" );
@@ -253,9 +177,6 @@ sub dir_go_west {
 }
 
 
-=item dir_go_north(  )
-
-=cut
 sub dir_go_north {
     my ($lbi) = @_;
     debug( "going north\n" );
@@ -263,9 +184,6 @@ sub dir_go_north {
 }
 
 
-=item dir_go_south(  )
-
-=cut
 sub dir_go_south {
     my ($lbi) = @_;
     debug( "going south\n" );
@@ -273,9 +191,6 @@ sub dir_go_south {
 }
 
 
-=item dir_go_high(  )
-
-=cut
 sub dir_go_high {
     my ($lbi) = @_;
     debug( "going high\n" );
@@ -283,9 +198,6 @@ sub dir_go_high {
 }
 
 
-=item dir_go_low(  )
-
-=cut
 sub dir_go_low {
     my ($lbi) = @_;
     debug( "going low\n" );
@@ -293,9 +205,6 @@ sub dir_go_low {
 }
 
 
-=item dir_go_away(  )
-
-=cut
 sub dir_go_away {
     my ($lbi) = @_;
     debug( "going away!\n" );
@@ -303,12 +212,6 @@ sub dir_go_away {
 }
 
 
-=item dir_turn_left(  )
-
-Turning left, like a car (the specs speak about a bicycle, but perl
-is _so_ fast that we can speak about cars ;) ).
-
-=cut
 sub dir_turn_left {
     my ($lbi) = @_;
     debug( "turning on the left\n" );
@@ -316,12 +219,6 @@ sub dir_turn_left {
 }
 
 
-=item dir_turn_right(  )
-
-Turning right, like a car (the specs speak about a bicycle, but perl
-is _so_ fast that we can speak about cars ;) ).
-
-=cut
 sub dir_turn_right {
     my ($lbi) = @_;
     debug( "turning on the right\n" );
@@ -329,9 +226,6 @@ sub dir_turn_right {
 }
 
 
-=item dir_reverse(  )
-
-=cut
 sub dir_reverse {
     my ($lbi) = @_;
     debug( "180 deg!\n" );
@@ -339,11 +233,6 @@ sub dir_reverse {
 }
 
 
-=item dir_set_delta(  )
-
-Hmm, the user seems to know where he wants to go. Let's trust him/her.
-
-=cut
 sub dir_set_delta {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -352,17 +241,6 @@ sub dir_set_delta {
     $ip->set_delta( $new_d );
 }
 
-=back
-
-
-
-=head2 Decision making
-
-=over 4
-
-=item decis_neg(  )
-
-=cut
 sub decis_neg {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -375,9 +253,6 @@ sub decis_neg {
 }
 
 
-=item decis_gt(  )
-
-=cut
 sub decis_gt {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -389,9 +264,6 @@ sub decis_gt {
 }
 
 
-=item decis_horiz_if(  )
-
-=cut
 sub decis_horiz_if {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -403,9 +275,6 @@ sub decis_horiz_if {
 }
 
 
-=item decis_vert_if(  )
-
-=cut
 sub decis_vert_if {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -417,9 +286,6 @@ sub decis_vert_if {
 }
 
 
-=item decis_z_if(  )
-
-=cut
 sub decis_z_if {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -431,9 +297,6 @@ sub decis_z_if {
 }
 
 
-=item decis_cmp(  )
-
-=cut
 sub decis_cmp {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -453,19 +316,6 @@ sub decis_cmp {
     debug( "comparing $v1 with $v2: turning: $dir\n" );
 }
 
-=back
-
-
-
-=head2 Flow control
-
-=over 4
-
-=item flow_space(  )
-
-A serie of spaces is to be treated as B<one> NO-OP.
-
-=cut
 sub flow_space {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -477,20 +327,12 @@ sub flow_space {
 }
 
 
-=item flow_no_op(  )
-
-=cut
 sub flow_no_op {
     my ($lbi) = @_;
     debug( "no-op\n" );
 }
 
 
-=item flow_comments(  )
-
-Bypass comments in B<zero> tick.
-
-=cut
 sub flow_comments {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -505,9 +347,6 @@ sub flow_comments {
 }
 
 
-=item flow_trampoline(  )
-
-=cut
 sub flow_trampoline {
     my ($lbi) = @_;
     $lbi->_move_ip_once($lbi->get_curip);
@@ -515,9 +354,6 @@ sub flow_trampoline {
 }
 
 
-=item flow_jump_to(  )
-
-=cut
 sub flow_jump_to {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -530,9 +366,6 @@ sub flow_jump_to {
 }
 
 
-=item flow_repeat(  )
-
-=cut
 sub flow_repeat {
     my ($lbi) = @_;
     my $ip  = $lbi->get_curip;
@@ -555,9 +388,6 @@ sub flow_repeat {
 }
 
 
-=item flow_kill_thread(  )
-
-=cut
 sub flow_kill_thread {
     my ($lbi) = @_;
     debug( "end of Instruction Pointer\n" );
@@ -565,9 +395,6 @@ sub flow_kill_thread {
 }
 
 
-=item flow_quit(  )
-
-=cut
 sub flow_quit {
     my ($lbi) = @_;
     debug( "end program\n" );
@@ -577,17 +404,6 @@ sub flow_quit {
     $lbi->set_retval( $lbi->get_curip->spop );
 }
 
-=back
-
-
-
-=head2 Stack manipulation
-
-=over 4
-
-=item stack_pop(  )
-
-=cut
 sub stack_pop {
     my ($lbi) = @_;
     debug( "popping a value\n" );
@@ -595,9 +411,6 @@ sub stack_pop {
 }
 
 
-=item stack_duplicate(  )
-
-=cut
 sub stack_duplicate {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -608,9 +421,6 @@ sub stack_duplicate {
 }
 
 
-=item stack_swap(  )
-
-=cut
 sub stack_swap {
     my ($lbi) = @_;
     my $ ip = $lbi->get_curip;
@@ -621,26 +431,12 @@ sub stack_swap {
 }
 
 
-=item stack_clear(  )
-
-=cut
 sub stack_clear {
     my ($lbi) = @_;
     debug( "clearing stack\n" );
     $lbi->get_curip->sclear;
 }
 
-=back
-
-
-
-=head2 Stack stack manipulation
-
-=over 4
-
-=item block_open(  )
-
-=cut
 sub block_open {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -661,9 +457,6 @@ sub block_open {
 }
 
 
-=item block_close(  )
-
-=cut
 sub block_close {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -681,9 +474,6 @@ sub block_close {
 }
 
 
-=item bloc_transfer(  )
-
-=cut
 sub bloc_transfer {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -695,17 +485,6 @@ sub bloc_transfer {
     $ip->ss_transfer( $ip->spop );
 }
 
-=back
-
-
-
-=head2 Funge-space storage
-
-=over 4
-
-=item store_get(  )
-
-=cut
 sub store_get {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -722,9 +501,6 @@ sub store_get {
 }
 
 
-=item store_put(  )
-
-=cut
 sub store_put {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -740,17 +516,6 @@ sub store_put {
     debug( "storing value $val at $v\n" );
 }
 
-=back
-
-
-
-=head2 Standard Input/Output
-
-=over 4
-
-=item stdio_out_num(  )
-
-=cut
 sub stdio_out_num {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -762,9 +527,6 @@ sub stdio_out_num {
 }
 
 
-=item stdio_out_ascii(  )
-
-=cut
 sub stdio_out_ascii {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -777,9 +539,6 @@ sub stdio_out_ascii {
 }
 
 
-=item stdio_in_num(  )
-
-=cut
 sub stdio_in_num {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -806,9 +565,6 @@ sub stdio_in_num {
 }
 
 
-=item stdio_in_ascii(  )
-
-=cut
 sub stdio_in_ascii {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -820,9 +576,6 @@ sub stdio_in_ascii {
 }
 
 
-=item stdio_in_file(  )
-
-=cut
 sub stdio_in_file {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -851,9 +604,6 @@ sub stdio_in_file {
 }
 
 
-=item stdio_out_file(  )
-
-=cut
 sub stdio_out_file {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -883,9 +633,6 @@ sub stdio_out_file {
 }
 
 
-=item stdio_sys_exec(  )
-
-=cut
 sub stdio_sys_exec {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -897,17 +644,6 @@ sub stdio_sys_exec {
     $ip->spush( $? == -1 ? -1 : $? >> 8 );
 }
 
-=back
-
-
-
-=head2 System info retrieval
-
-=over 4
-
-=item sys_info(  )
-
-=cut
 sub sys_info {
     my ($lbi) = @_;
     my $ip      = $lbi->get_curip;
@@ -1025,17 +761,6 @@ sub sys_info {
     }
 }
 
-=back
-
-
-
-=head2 Concurrent Funge
-
-=over 4
-
-=item spawn_ip(  )
-
-=cut
 sub spawn_ip {
     my ($lbi) = @_;
 
@@ -1049,17 +774,6 @@ sub spawn_ip {
     push @{ $lbi->get_newips }, $newip;
 }
 
-=back
-
-
-
-=head2 Library semantics
-
-=over 4
-
-=item lib_load(  )
-
-=cut
 sub lib_load {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -1098,9 +812,6 @@ sub lib_load {
 }
 
 
-=item lib_unload(  )
-
-=cut
 sub lib_unload {
     my ($lbi) = @_;
     my $ip = $lbi->get_curip;
@@ -1137,9 +848,6 @@ sub lib_unload {
     }
 }
 
-=item lib_run_instruction( )
-
-=cut
 
 sub lib_run_instruction {
     my ($lbi) = @_;
@@ -1161,33 +869,242 @@ sub lib_run_instruction {
     }
 }
 
-=back
-
-=cut
 
 1;
 
 __END__
 
-=head1 SEE ALSO
+=pod
 
-L<Language::Befunge>
+=encoding UTF-8
 
+=head1 NAME
+
+Language::Befunge::Ops - definition of the various operations
+
+=head1 VERSION
+
+version 5.000
+
+=head1 DESCRIPTION
+
+This module implements the various befunge operations. Not all those
+operations will be supported by the interpreter though, it will depend
+on the type of befunge chosen.
+
+=head1 SUBROUTINES
+
+=head2 Numbers
+
+=over 4
+
+=item num_push_number(  )
+
+Push the current number onto the TOSS.
+
+=back
+
+=head2 Strings
+
+=over 4
+
+=item str_enter_string_mode(  )
+
+=item str_fetch_char(  )
+
+=item str_store_char(  )
+
+=back
+
+=head2 Mathematical operations
+
+=over 4
+
+=item math_addition(  )
+
+=item math_substraction(  )
+
+=item math_multiplication(  )
+
+=item math_division(  )
+
+=item math_remainder(  )
+
+=back
+
+=head2 Direction changing
+
+=over 4
+
+=item dir_go_east(  )
+
+=item dir_go_west(  )
+
+=item dir_go_north(  )
+
+=item dir_go_south(  )
+
+=item dir_go_high(  )
+
+=item dir_go_low(  )
+
+=item dir_go_away(  )
+
+=item dir_turn_left(  )
+
+Turning left, like a car (the specs speak about a bicycle, but perl
+is _so_ fast that we can speak about cars ;) ).
+
+=item dir_turn_right(  )
+
+Turning right, like a car (the specs speak about a bicycle, but perl
+is _so_ fast that we can speak about cars ;) ).
+
+=item dir_reverse(  )
+
+=item dir_set_delta(  )
+
+Hmm, the user seems to know where he wants to go. Let's trust him/her.
+
+=back
+
+=head2 Decision making
+
+=over 4
+
+=item decis_neg(  )
+
+=item decis_gt(  )
+
+=item decis_horiz_if(  )
+
+=item decis_vert_if(  )
+
+=item decis_z_if(  )
+
+=item decis_cmp(  )
+
+=back
+
+=head2 Flow control
+
+=over 4
+
+=item flow_space(  )
+
+A serie of spaces is to be treated as B<one> NO-OP.
+
+=item flow_no_op(  )
+
+=item flow_comments(  )
+
+Bypass comments in B<zero> tick.
+
+=item flow_trampoline(  )
+
+=item flow_jump_to(  )
+
+=item flow_repeat(  )
+
+=item flow_kill_thread(  )
+
+=item flow_quit(  )
+
+=back
+
+=head2 Stack manipulation
+
+=over 4
+
+=item stack_pop(  )
+
+=item stack_duplicate(  )
+
+=item stack_swap(  )
+
+=item stack_clear(  )
+
+=back
+
+=head2 Stack stack manipulation
+
+=over 4
+
+=item block_open(  )
+
+=item block_close(  )
+
+=item bloc_transfer(  )
+
+=back
+
+=head2 Funge-space storage
+
+=over 4
+
+=item store_get(  )
+
+=item store_put(  )
+
+=back
+
+=head2 Standard Input/Output
+
+=over 4
+
+=item stdio_out_num(  )
+
+=item stdio_out_ascii(  )
+
+=item stdio_in_num(  )
+
+=item stdio_in_ascii(  )
+
+=item stdio_in_file(  )
+
+=item stdio_out_file(  )
+
+=item stdio_sys_exec(  )
+
+=back
+
+=head2 System info retrieval
+
+=over 4
+
+=item sys_info(  )
+
+=back
+
+=head2 Concurrent Funge
+
+=over 4
+
+=item spawn_ip(  )
+
+=back
+
+=head2 Library semantics
+
+=over 4
+
+=item lib_load(  )
+
+=item lib_unload(  )
+
+=item lib_run_instruction( )
+
+=back
 
 =head1 AUTHOR
 
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
-Development is discussed on E<lt>language-befunge@mongueurs.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
