@@ -1,18 +1,18 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Ops::GenericFunge98;
-require 5.010;
-
+use 5.010;
 use strict;
 use warnings;
 
+package Language::Befunge::Ops::GenericFunge98;
+# ABSTRACT: operations supported by a Trifunge-98 interpreter
+$Language::Befunge::Ops::GenericFunge98::VERSION = '5.000';
 use Language::Befunge::Ops;
 
 sub get_ops_map {
@@ -119,10 +119,17 @@ sub get_ops_map {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Language::Befunge::Ops::GenericBefunge98 - operations supported by a Trifunge-98 interpreter
+Language::Befunge::Ops::GenericFunge98 - operations supported by a Trifunge-98 interpreter
 
+=head1 VERSION
+
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -140,26 +147,15 @@ operations.
 
 =back
 
-
-=head1 SEE ALSO
-
-L<Language::Befunge>
-
-
 =head1 AUTHOR
 
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
-Development is discussed on E<lt>language-befunge@mongueurs.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
