@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2008 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Storage;
-
 use strict;
 use warnings;
 
+package Language::Befunge::Storage;
+# ABSTRACT: a generic Storage base class for Language::Befunge
+$Language::Befunge::Storage::VERSION = '5.000';
 use Carp;
 use Language::Befunge::Vector;
 use Language::Befunge::IP;
@@ -367,12 +367,20 @@ sub _labels_try {
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Language::Befunge::Storage - a generic Storage base class
+Language::Befunge::Storage - a generic Storage base class for Language::Befunge
 
+=head1 VERSION
+
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -383,7 +391,6 @@ Language::Befunge::Storage - a generic Storage base class
     67890
     EOF
 
-
 =head1 DESCRIPTION
 
 This class implements a set of basic methods which can be used by all
@@ -397,16 +404,12 @@ maximum vector sizes stored as "min" and "max", respectively.  No
 other assumptions about the storage model are made; they just call
 expand, get_value and set_value to do their dirty work.
 
-
 =head1 PUBLIC METHODS
 
-
 =head2 Storage update
 
-
 =over 4
 
-
 =item my $size = $storage->store_binary( $code [, $position] );
 
 Store the given C<$code> at the specified C<$position> (defaulting to
@@ -418,7 +421,6 @@ The code is a string, representing a block of Funge code. This is binary
 insertion, that is, EOL sequences are stored in Funge-space instead of
 causing the dimension counters to be resetted and incremented.
 
-
 =item my $size = $storage->store( $code [, $position] );
 
 Store the given $code at the specified $position (defaulting to the
@@ -429,7 +431,6 @@ Return the size of the code inserted, as a vector.
 The code is a string, representing a block of Funge code. Rows are
 separated by newlines.
 
-
 =item $storage->expand( vector );
 
 Expand the storage range to include the specified point, if necessary.
@@ -444,31 +445,24 @@ reaches new ground.
 Sparse storage models do not need this; all other storage models should
 implement a specific method to resize their data structure.
 
-
 =back
 
-
 =head2 Data retrieval
 
-
 =over 4
 
-
 =item my $dims = $storage->get_dims;
 
 Return the number of dimensions this storage object operates in.
 
-
 =item my $vmin = $storage->min;
 
 Return a LBV pointing to the lower bounds of the storage.
 
-
 =item my $vmax = $storage->max;
 
 Return a LBV pointing to the upper bounds of the storage.
 
-
 =item my $chr = $storage->get_char( $offset )
 
 Return the character stored in the torus at the specified C<$offset>. If
@@ -479,22 +473,17 @@ B</!\> As in Befunge, code and data share the same playfield, the
 character returned can be either an instruction B<or> raw data. No
 guarantee is made that the return value is printable.
 
-
 =item my $str = $storage->rectangle( $pos, $size );
 
 Return a string containing the data/code in the rectangle defined by
 the supplied vectors.
 
-
 =back
 
-
 =head2 Miscellaneous methods
 
-
 =over 4
 
-
 =item my $href = $storage->labels_lookup;
 
 Parse the storage to find sequences such as C<;:(\w[^\s;])[^;]*;>
@@ -510,7 +499,6 @@ since we're only using cardinal directions)
 This allow to define some labels in the source code, to be used by
 C<Inline::Befunge> (and maybe some exstensions).
 
-
 =begin pod_coverage
 
 =item LBV - alias for Language::Befunge::Vector
@@ -519,25 +507,15 @@ C<Inline::Befunge> (and maybe some exstensions).
 
 =back
 
-
-
-=head1 SEE ALSO
-
-L<Language::Befunge>.
-
-
 =head1 AUTHOR
 
-Mark Glines, C<< <infinoid@cpan.org> >>
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2003 by Jerome Quelin.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
