@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Storage::2D::Sparse;
-
 use strict;
 use warnings;
 
+package Language::Befunge::Storage::2D::Sparse;
+# ABSTRACT: a 2D storage, using sparse hash
+$Language::Befunge::Storage::2D::Sparse::VERSION = '5.000';
 use Carp;
 use aliased 'Language::Befunge::Vector' => 'LBV';
 use Readonly;
@@ -348,12 +348,20 @@ sub _labels_try {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-LBS::2D::Sparse - a 2D storage, using sparse hash
+Language::Befunge::Storage::2D::Sparse - a 2D storage, using sparse hash
 
+=head1 VERSION
+
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -364,7 +372,6 @@ LBS::2D::Sparse - a 2D storage, using sparse hash
     67890
     EOF
 
-
 =head1 DESCRIPTION
 
 This class implements a storage as defined in LBS. It makes the
@@ -375,36 +382,26 @@ This storage is sparse, using a private hash with keys such as "$x,$y".
 Any value of a non-existing key defaults to 32 (space), as defined by
 funge specs.
 
-
-
 =head1 PUBLIC METHODS
 
-
 =head2 Constructor
 
-
 =over 4
 
 =item my $storage = LBS::2D::Sparse->new;
 
 Create a new LBS object.
 
-
 =back
 
-
-
 =head2 Storage update
 
-
 =over 4
 
-
 =item $storage->clear;
 
 Clear the storage.
 
-
 =item my $size = $storage->store_binary( $code [, $position] );
 
 Store the given C<$code> at the specified C<$position> (defaulting to
@@ -416,7 +413,6 @@ The code is a string, representing a block of Funge code. This is binary
 insertion, that is, EOL sequences are stored in Funge-space instead of
 causing the dimension counters to be resetted and incremented.
 
-
 =item my $size = $storage->store( $code [, $position] );
 
 Store the given $code at the specified $position (defaulting to the
@@ -427,7 +423,6 @@ Return the size of the code inserted, as a vector.
 The code is a string, representing a block of Funge code. Rows are
 separated by newlines.
 
-
 =item $storage->set_value( $offset, $value );
 
 Write the supplied C<$value> in the storage at the specified C<$offset>.
@@ -436,33 +431,25 @@ B</!\> As in Befunge, code and data share the same playfield, the number
 stored can be either an instruction B<or> raw data (or even both... Eh,
 that's Befunge! :o) ).
 
-
 =back
 
-
-
 =head2 Data retrieval
 
-
 =over 4
 
-
 =item my $dims = $storage->get_dims;
 
 Return the dimensionality of the storage.  For this module, the value is
 always 2.
 
-
 =item my $vmin = $storage->min;
 
 Return a LBV pointing to the lower bounds of the storage.
 
-
 =item my $vmax = $storage->max;
 
 Return a LBV pointing to the upper bounds of the storage.
 
-
 =item my $val = $storage->get_value( $offset );
 
 Return the number stored in the torus at the specified C<$offset>. If
@@ -473,7 +460,6 @@ B</!\> As in Befunge, code and data share the same playfield, the number
 returned can be either an instruction B<or> raw data (or even both... Eh,
 that's Befunge! :o) ).
 
-
 =item my $chr = $storage->get_char( $offset )
 
 Return the character stored in the torus at the specified C<$offset>. If
@@ -484,22 +470,17 @@ B</!\> As in Befunge, code and data share the same playfield, the
 character returned can be either an instruction B<or> raw data. No
 guarantee is made that the return value is printable.
 
-
 =item my $str = $storage->rectangle( $pos, $size );
 
 Return a string containing the data/code in the rectangle defined by
 the supplied vectors.
 
-
 =back
 
-
 =head2 Miscellaneous methods
 
-
 =over 4
 
-
 =item my $href = $storage->labels_lookup;
 
 Parse the storage to find sequences such as C<;:(\w[^\s;])[^;]*;>
@@ -515,7 +496,6 @@ since we're only using cardinal directions)
 This allow to define some labels in the source code, to be used by
 C<Inline::Befunge> (and maybe some exstensions).
 
-
 =begin pod_coverage
 
 =item LBV - alias for Language::Befunge::Vector
@@ -524,24 +504,15 @@ C<Inline::Befunge> (and maybe some exstensions).
 
 =back
 
-
-
-=head1 SEE ALSO
-
-L<Language::Befunge>.
-
-
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2003 by Jerome Quelin.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
