@@ -1,16 +1,18 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Storage::Generic::Sparse;
-require 5.010;
+use 5.010;
 use strict;
 use warnings;
+
+package Language::Befunge::Storage::Generic::Sparse;
+# ABSTRACT: a generic N-dimensional LaheySpace
+$Language::Befunge::Storage::Generic::Sparse::VERSION = '5.000';
 use Carp;
 use Language::Befunge::Vector;
 use Language::Befunge::IP;
@@ -96,12 +98,20 @@ sub set_value {
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Language::Befunge::Storage::Generic::Sparse - a generic N-dimensional LaheySpace.
+Language::Befunge::Storage::Generic::Sparse - a generic N-dimensional LaheySpace
 
+=head1 VERSION
+
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -118,28 +128,24 @@ Language::Befunge::Storage::Generic::Sparse - a generic N-dimensional LaheySpace
 Note you usually don't need to use this module directly.
 B<Language::Befunge::Interpreter> can optionally use it.
 
-
 =head1 DESCRIPTION
 
 This module implements an N-dimensional storage space, as a sparse hash.  The
 values in the hash are keyed by coordinate strings, as created by stringifying
 a Vector object.
 
-
 =head1 CONSTRUCTOR
 
 =head2 new( dimensions )
 
 Creates a new Lahey Space.
 
-
 =head1 PUBLIC METHODS
 
 =head2 clear(  )
 
 Clear the torus.
 
-
 =head2 get_value( vector )
 
 Return the number stored in the torus at the specified location. If
@@ -150,7 +156,6 @@ B</!\> As in Funge, code and data share the same playfield, the
 number returned can be either an instruction B<or> a data (or even
 both... Eh, that's Funge! :o) ).
 
-
 =head2 set_value( vector, value )
 
 Write the supplied value in the torus at the specified location.
@@ -159,7 +164,6 @@ B</!\> As in Funge, code and data share the same playfield, the
 number stored can be either an instruction B<or> a data (or even
 both... Eh, that's Funge! :o) ).
 
-
 =head1 EXTERNAL METHODS
 
 Several methods are inherited from the Language::Befunge::Storage base
@@ -178,32 +182,23 @@ class.  These methods are:
 
 Please see the documentation of that module for more information.
 
-
 =head1 BUGS
 
 None known.  Please inform me if you find one.
 
-
 =head1 SEE ALSO
 
-<Language::Befunge::Storage>, L<Language::Befunge::Storage::2D::Sparse>,
-L<Language::Befunge>.
-
+<Language::Befunge::Storage>, L<Language::Befunge::Storage::2D::Sparse>.
 
 =head1 AUTHOR
 
-Mark Glines, E<lt>infinoid@cpan.orgE<gt>
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
-Development is discussed on E<lt>language-befunge@mongueurs.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
