@@ -1,16 +1,18 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Storage::Generic::Vec;
-require 5.010;
+use 5.010;
 use strict;
 use warnings;
+
+package Language::Befunge::Storage::Generic::Vec;
+# ABSTRACT: a generic N-dimensional LaheySpace
+$Language::Befunge::Storage::Generic::Vec::VERSION = '5.000';
 no warnings 'portable'; # "Bit vector size > 32 non-portable" warnings on x64
 use Carp;
 use Language::Befunge::Vector;
@@ -229,12 +231,20 @@ sub _copy {
 sub _is_xs { 0 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Language::Befunge::Storage::Generic::Vec - a generic N-dimensional LaheySpace.
+Language::Befunge::Storage::Generic::Vec - a generic N-dimensional LaheySpace
 
+=head1 VERSION
+
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -256,31 +266,26 @@ dreadfully slow without it.  If you cannot install that, you should
 use L<Language::Befunge::Storage::Generic::AoA> instead, it will perform
 better.
 
-
 =head1 DESCRIPTION
 
 This module implements a traditional Lahey space.
 
-
 =head1 CONSTRUCTOR
 
 =head2 new( dimensions )
 
 Creates a new Lahey Space.
 
-
 =head1 PUBLIC METHODS
 
 =head2 clear(  )
 
 Clear the torus.
 
-
 =head2 expand( v )
 
 Expand the torus to include the provided point.
 
-
 =head2 get_value( vector )
 
 Return the number stored in the torus at the specified location. If
@@ -291,7 +296,6 @@ B</!\> As in Funge, code and data share the same playfield, the
 number returned can be either an instruction B<or> a data (or even
 both... Eh, that's Funge! :o) ).
 
-
 =head2 set_value( vector, value )
 
 Write the supplied value in the torus at the specified location.
@@ -300,7 +304,6 @@ B</!\> As in Funge, code and data share the same playfield, the
 number stored can be either an instruction B<or> a data (or even
 both... Eh, that's Funge! :o) ).
 
-
 =head1 EXTERNAL METHODS
 
 Several methods are inherited from the Language::Befunge::Storage base
@@ -318,32 +321,23 @@ class.  These methods are:
 
 Please see the documentation of that module for more information.
 
-
 =head1 BUGS
 
 None known.  Please inform me if you find one.
 
-
 =head1 SEE ALSO
 
-L<Language::Befunge::Storage::Generic::Vec::XS>, L<Language::Befunge::Storage>,
-L<Language::Befunge>.
-
+L<Language::Befunge::Storage::Generic::Vec::XS>, L<Language::Befunge::Storage>.
 
 =head1 AUTHOR
 
-Mark Glines, E<lt>infinoid@cpan.orgE<gt>
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
-Development is discussed on E<lt>language-befunge@mongueurs.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
