@@ -1,16 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Vector;
-
 use strict;
 use warnings;
+
+package Language::Befunge::Vector;
+# ABSTRACT: an opaque, N-dimensional vector class
+$Language::Befunge::Vector::VERSION = '5.000';
 use integer;
 use Carp;
 
@@ -382,21 +383,26 @@ sub _xs_rasterize_ptr { return undef }
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Language::Befunge::Vector - an opaque, N-dimensional vector class.
+Language::Befunge::Vector - an opaque, N-dimensional vector class
 
+=head1 VERSION
 
+version 5.000
 
 =head1 SYNOPSIS
 
     my $v1 = Language::Befunge::Vector->new($x, $y, ...);
     my $v2 = Language::Befunge::Vector->new_zeroes($dims);
 
-
-
 =head1 DESCRIPTION
 
 This class abstracts normal vector manipulation. It lets you pass
@@ -407,8 +413,6 @@ how many dimensions you're working with.
 You can do vector arithmetic, test for equality, or even stringify
 the vector to a string like I<"(1,2,3)">.
 
-
-
 =head1 CONSTRUCTORS
 
 =head2 my $vec = LB::Vector->new( $x [, $y, ...] )
@@ -416,20 +420,16 @@ the vector to a string like I<"(1,2,3)">.
 Create a new vector. The arguments are the actual vector data; one
 integer per dimension.
 
-
 =head2 my $vec = LB::Vector->new_zeroes($dims);
 
 Create a new vector of dimension C<$dims>, set to the origin (all zeroes). C<<
 LBV->new_zeroes(2) >> is exactly equivalent to B<< LBV->new(0,0) >>.
 
-
 =head2 my $vec = $v->copy;
 
 Return a new LBV object, which has the same dimensions and coordinates
 as $v.
 
-
-
 =head1 PUBLIC METHODS
 
 =head2 my $str = $vec->as_string;
@@ -440,38 +440,31 @@ might look like C<(1,2)>.
 This method is also applied to stringification, ie when one forces
 string context (C<"$vec">).
 
-
 =head2 my $dims = $vec->get_dims;
 
 Return the number of dimensions, an integer.
 
-
 =head2 my $val = $vec->get_component($dim);
 
 Get the value for dimension C<$dim>.
 
-
 =head2 my @vals = $vec->get_all_components;
 
 Get the values for all dimensions, in order from 0..N.
 
-
 =head2 $vec->clear;
 
 Set the vector back to the origin, all 0's.
 
-
 =head2 $vec->set_component($dim, $value);
 
 Set the value for dimension C<$dim> to C<$value>.
 
-
 =head2 my $is_within = $vec->bounds_check($begin, $end);
 
 Check whether C<$vec> is within the box defined by C<$begin> and C<$end>.
 Return 1 if vector is contained within the box, and 0 otherwise.
 
-
 =head2 $vec->rasterize($min, $max);
 
 Return the next vector in raster order, or undef if the hypercube space
@@ -483,8 +476,6 @@ the return value is defined.  To enumerate a smaller rectangle, the
 caller should pass in the min and max vectors describing the rectangle,
 and keep looping while the return value is defined.
 
-
-
 =head1 MATHEMATICAL OPERATIONS
 
 =head2 Standard operations
@@ -505,7 +496,6 @@ will subtracts C<$v1> from the origin, and effectively, gives the
 inverse of the original vector. The new vector is the same distance from
 the origin, in the opposite direction.
 
-
 =head2 Inplace operations
 
 LBV objects also supports inplace mathematical operations:
@@ -516,7 +506,6 @@ LBV objects also supports inplace mathematical operations:
 effectively adds / substracts C<$v2> to / from C<$v1>, and stores the
 result back into C<$v1>.
 
-
 =head2 Comparison
 
 Finally, LBV objects can be tested for equality, ie whether two vectors
@@ -525,7 +514,6 @@ both point at the same spot.
     print "same"   if $v1 == $v2;
     print "differ" if $v1 != $v2;
 
-
 =head1 PRIVATE METHODS
 
 =head2 _xs_rasterize_ptr
@@ -543,26 +531,15 @@ The prototype of the C rasterize function is:
 It operates just like the perl rasterize function, and returns NULL when the
 end of the loop has been reached.
 
-
-=head1 SEE ALSO
-
-L<Language::Befunge>
-
-
 =head1 AUTHOR
 
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
-Development is discussed on E<lt>language-befunge@mongueurs.netE<gt>
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
