@@ -1,17 +1,18 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::Wrapping;
-
 use strict;
 use warnings;
 
+package Language::Befunge::Wrapping;
+# ABSTRACT: base wrapping class
+$Language::Befunge::Wrapping::VERSION = '5.000';
+
 # -- CONSTRUCTOR
 
 use Class::XSAccessor constructor => 'new';
@@ -32,28 +33,32 @@ use Class::XSAccessor constructor => 'new';
 sub wrap { die 'wrapping not implemented in LBW'; }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Language::Befunge::Wrapping - base wrapping class
 
+=head1 VERSION
+
+version 5.000
 
 =head1 DESCRIPTION
 
 C<LBW> implements a wrapping that dies. It's meant to be overridden by
 other wrapping classes.
 
-
-
 =head1 CONSTRUCTOR
 
 =head2 LBW->new;
 
 Creates a new wrapping object.
 
-
 =head1 PUBLIC METHODS
 
 =head2 $wrapping->wrap( $storage, $ip )
@@ -66,25 +71,15 @@ LBI.
 
 As a side effect, $ip will have its position changed.
 
-
-
-=head1 SEE ALSO
-
-L<Language::Befunge>.
-
-
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2003 by Jerome Quelin.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
