@@ -1,18 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::lib::BOOL;
-
 use strict;
 use warnings;
 
-
+package Language::Befunge::lib::BOOL;
+# ABSTRACT: Boolean operations extension
+$Language::Befunge::lib::BOOL::VERSION = '5.000';
 sub new { return bless {}, shift; }
 
 
@@ -95,26 +94,28 @@ sub X {
 
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Language::Befunge::IP::lib::BOOL - Boolean operations extension
+Language::Befunge::lib::BOOL - Boolean operations extension
 
+=head1 VERSION
 
+version 5.000
 
 =head1 DESCRIPTION
 
 The BOOL fingerprint (0x424F4F4C) allows to do Boole logical operations.
 
-
-
 =head1 FUNCTIONS
 
 =head2 new
 
 Create a new BOOL instance.
 
-
 =head2 Bit operations
 
 =over 4
@@ -123,43 +124,33 @@ Create a new BOOL instance.
 
 Push back C<$a AND $b> (logical AND).
 
-
 =item O( $a, $b )
 
 Push back C<$a OR $b> (logical OR).
 
-
 =item N( $a )
 
 Push back C<NOT $ab> (logical NOT).
 
-
 =item X( $a, $b )
 
 Push back C<$a XOR $b> (logical XOR).
 
-
 =back
 
-
-
 =head1 SEE ALSO
 
-L<Language::Befunge>, L<http://www.rcfunge98.com/rcsfingers.html#BOOL>.
-
-
+L<http://www.rcfunge98.com/rcsfingers.html#BOOL>.
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2003 by Jerome Quelin.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
