@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::lib::HELO;
-
 use strict;
 use warnings;
 
+package Language::Befunge::lib::HELO;
+# ABSTRACT: extension to print Hello world!
+$Language::Befunge::lib::HELO::VERSION = '5.000';
 sub new { return bless {}, shift; }
 
 sub P {
@@ -25,13 +25,20 @@ sub S {
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Language::Befunge::IP::lib::HELO - a Befunge extension to print Hello world!
+Language::Befunge::lib::HELO - extension to print Hello world!
 
+=head1 VERSION
+
+version 5.000
 
 =head1 SYNOPSIS
 
@@ -43,40 +50,29 @@ Language::Befunge::IP::lib::HELO - a Befunge extension to print Hello world!
 This extension is just an example of the Befunge extension mechanism
 of the Language::Befunge interpreter.
 
-
 =head1 FUNCTIONS
 
 =head2 new
 
 Create a new HELO instance.
 
-
 =head2 P
 
 Output C<Hello world!\n>.
 
-
 =head2 S
 
 Store the gnirts "Hello world!\n"0 on the TOSS.
 
-
-=head1 SEE ALSO
-
-L<Language::Befunge>.
-
-
 =head1 AUTHOR
 
-Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2003 by Jerome Quelin.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
