@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::lib::NULL;
-
 use strict;
 use warnings;
 
+package Language::Befunge::lib::NULL;
+# ABSTRACT: Extension to opacify loaded extensions
+$Language::Befunge::lib::NULL::VERSION = '5.000';
 sub new { return bless {}, shift; }
 
 
@@ -32,14 +32,20 @@ BEGIN {
 
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Language::Befunge::IP::lib::NULL - Extension to opacify loaded extensions
+Language::Befunge::lib::NULL - Extension to opacify loaded extensions
 
+=head1 VERSION
 
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -49,15 +55,12 @@ instructions A to Z take the semantics of r.
 This can be loaded before loading a regular transparent fingerprint to make
 it act opaquely.
 
-
-
 =head1 FUNCTIONS
 
 =head2 new
 
 Create a new NULL instance.
 
-
 =head2 Opacification
 
 =over 4
@@ -68,26 +71,19 @@ All the library instructions reflect current IP (same as instruction C<r>).
 
 =back
 
-
-
 =head1 SEE ALSO
 
-L<Language::Befunge>, L<http://catseye.tc/projects/funge98/library/NULL.html>.
-
-
+L<http://catseye.tc/projects/funge98/library/NULL.html>.
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
