@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::lib::PERL;
-
 use strict;
 use warnings;
 
+package Language::Befunge::lib::PERL;
+# ABSTRACT: extension to embed Perl within Befunge
+$Language::Befunge::lib::PERL::VERSION = '5.000';
 
 sub new { return bless {}, shift; }
 
@@ -71,12 +71,17 @@ sub S {
 
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Language::Befunge::IP::lib::PERL - extension to embed Perl within Befunge
+Language::Befunge::lib::PERL - extension to embed Perl within Befunge
 
+=head1 VERSION
 
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -86,16 +91,12 @@ interface to the Perl language.
 After successfully loading PERL, the instructions E, I, and S take on new
 semantics.
 
-
-
 =head1 FUNCTIONS
 
 =head2 new
 
 Create a new PERL instance.
 
-
-
 =head2 Module information
 
 =over 4
@@ -107,7 +108,6 @@ loaded (e.g. the interpreter is written in Perl).
 
 =back
 
-
 =head2 Perl embedding
 
 =over 4
@@ -117,35 +117,26 @@ loaded (e.g. the interpreter is written in Perl).
 C<Eval> pops a 0gnirts string and performs a Perl C<eval()> on it. The
 result of the call is pushed as a 0gnirts string back onto the stack.
 
-
 =item val = I( 0gnirts )
 
 C<Int Eval> acts the same as C<E>, except that the result of the call
 is converted to an integer and pushed as a single cell onto the stack. 
 
-
 =back
 
-
-
 =head1 SEE ALSO
 
-L<Language::Befunge>, L<http://catseye.tc/projects/funge98/library/PERL.html>.
-
-
+L<http://catseye.tc/projects/funge98/library/PERL.html>.
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
