@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::lib::REFC;
-
 use strict;
 use warnings;
 
+package Language::Befunge::lib::REFC;
+# ABSTRACT: Referenced cells extension
+$Language::Befunge::lib::REFC::VERSION = '5.000';
 use Language::Befunge::Vector;
 
 sub new { return bless {}, shift; }
@@ -54,31 +54,32 @@ sub D {
 
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Language::Befunge::IP::lib::REFC - Referenced cells extension
+Language::Befunge::lib::REFC - Referenced cells extension
 
+=head1 VERSION
 
+version 5.000
 
 =head1 DESCRIPTION
 
-
 The REFC fingerprint (0x52454643) allows vectors to be encoded into and
 decoded from single scalar cell values.
 
 Note that the internal list of references is considered shared among all
 IP's. 
 
-
-
 =head1 FUNCTIONS
 
 =head2 new
 
 Create a new REFC instance.
 
-
 =head2 De/Referencing
 
 =over 4
@@ -89,34 +90,26 @@ C<Reference> pops a vector off the stack, and pushes a scalar value back onto
 the stack, unique within an internal list of references, which refers to that
 vector.
 
-
 =item ($x, $y) = D( $id )
 
 C<Dereference> pops a scalar value off the stack, and pushes the vector back
 onto the stack which corresponds to that unique reference value.
 
-
 =back
 
-
-
 =head1 SEE ALSO
 
-L<Language::Befunge>, L<http://catseye.tc/projects/funge98/library/REFC.html>.
-
-
+L<http://catseye.tc/projects/funge98/library/REFC.html>.
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2003 by Jerome Quelin.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
