@@ -1,17 +1,17 @@
 #
-# This file is part of Language::Befunge.
-# Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
+# This file is part of Language-Befunge
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
+# This software is copyright (c) 2003 by Jerome Quelin.
 #
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
 #
-
-package Language::Befunge::lib::ROMA;
-
 use strict;
 use warnings;
 
+package Language::Befunge::lib::ROMA;
+#ABSTRACT: Roman numerals extension
+$Language::Befunge::lib::ROMA::VERSION = '5.000';
 use Language::Befunge::Vector;
 
 sub new { return bless {}, shift; }
@@ -41,12 +41,17 @@ sub X { $_[1]->get_curip->spush(10); }
 
 __END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Language::Befunge::IP::lib::ROMA - Roman numerals extension
+Language::Befunge::lib::ROMA - Roman numerals extension
 
+=head1 VERSION
 
+version 5.000
 
 =head1 DESCRIPTION
 
@@ -55,15 +60,12 @@ numbers. Note that the new instructions will just push digits, you still
 have to do the arithmetic yourself. Executing MCMLXXXIV will not leave 1984
 on the stack. But executing C<MCM\-+LXXX+++IV\-++> should.
 
-
-
 =head1 FUNCTIONS
 
 =head2 new
 
 Create a new ROMA instance.
 
-
 =head2 Roman numbers
 
 =over 4
@@ -74,26 +76,19 @@ Push the corresponding roman value (M=1000, D=500, etc.) onto the stack.
 
 =back
 
-
-
 =head1 SEE ALSO
 
-L<Language::Befunge>, L<http://catseye.tc/projects/funge98/library/ROMA.html>.
-
-
+L<http://catseye.tc/projects/funge98/library/ROMA.html>.
 
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+Jerome Quelin
 
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2003 by Jerome Quelin.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright (c) 2001-2009 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
